@@ -41,11 +41,7 @@ class RuleBank(metaclass=Singleton):  # FIXME design review singleton
 
     orm_objects = {}  # type: Dict[str, TableRules]
     """ Dict[mapped_class: str, List[TablesRules]] -- rules for a table """
-    _metadata = None
-    _base = None
     _at = datetime.now()
-    _session = None
-    _engine = None
 
     def __init__(self):
         self._metadata = None
